use flare::transform_editor::TransformEditor;
use flare_shader::Coefs;

struct TransformEditorApp {
    transform_editor: TransformEditor,
}

impl TransformEditorApp {
    fn new() -> Self {
        Self {
            transform_editor: TransformEditor::new()
        }
    }
}

impl eframe::App for TransformEditorApp {
    fn update(&mut self, ctx: &egui::Context, _frame: &mut eframe::Frame) {
        egui::TopBottomPanel::top("top_panel").show(ctx, |ui| {
            egui::menu::bar(ui, |ui| {
                ui.menu_button("File", |ui| {
                    if ui.button("Quit").clicked() {
                        ctx.send_viewport_cmd(egui::ViewportCommand::Close);
                    }
                });
                if ui.button("Add Transform").clicked() {
                    self.transform_editor.add_transform(Coefs::IDENTITY)
                }
            })
        });

        egui::TopBottomPanel::bottom("bottom_panel").show(ctx, |ui| {
            ui.label(format!("Transforms: {}", self.transform_editor.len()))
        });

        egui::CentralPanel::default().show(ctx, |ui| {
            self.transform_editor.ui(ui)
        });
    }
}

fn main() -> eframe::Result {
    env_logger::init();

    let initial_dimensions = egui::vec2(800., 600.);
    let native_options = eframe::NativeOptions {
        viewport: egui::ViewportBuilder::default().with_inner_size(initial_dimensions),
        renderer: eframe::Renderer::Wgpu,
        ..Default::default()
    };

    eframe::run_native(
        "transform_editor",
        native_options,
        Box::new(|cc| {
            Ok(Box::new(TransformEditorApp::new()))
        }),
    )
}